# Navigation Simulator for Mobile Robot

## Installation
NSMR can be installed from source code.
```
$ git clone https://github.com/Jumpei-Arima/Navigation_Simulator_for_Mobile_Robot
$ cd Navigation_Simulator_for_Mobile_Robot
$ pip install -e .
```

For examples see example
```
python examples/run_env.py
```
